==> ifcopenshell-0.7.0.250519-py310-none-manylinux_2_31_x86_64.whl: ifcopenshell/api/sequence/edit_work_calendar.py <==
# IfcOpenShell - IFC toolkit and geometry engine
# Copyright (C) 2021 Dion Moult <dion@thinkmoult.com>
#
# This file is part of IfcOpenShell.
#
# IfcOpenShell is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# IfcOpenShell is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with IfcOpenShell.  If not, see <http://www.gnu.org/licenses/>.
import ifcopenshell
from typing import Any


def edit_work_calendar(
    file: ifcopenshell.file, work_calendar: ifcopenshell.entity_instance, attributes: dict[str, Any]
) -> None:
    """Edits the attributes of an IfcWorkCalendar

    For more information about the attributes and data types of an
    IfcWorkCalendar, consult the IFC documentation.

    :param work_calendar: The IfcWorkCalendar entity you want to edit
    :type work_calendar: ifcopenshell.entity_instance
    :param attributes: a dictionary of attribute names and values.
    :type attributes: dict
    :return: None
    :rtype: None

    Example:

    .. code:: python

        # Let's create a new calendar.
        calendar = ifcopenshell.api.run("sequence.add_work_calendar", model, name="5 Day Week")

        # Let's give it a description
        ifcopenshell.api.run("sequence.edit_work_calendar", model,
            work_calendar=calendar, attributes={"Description": "Monday to Friday 8 hour days"})
    """
    settings = {"work_calendar": work_calendar, "attributes": attributes}

    for name, value in settings["attributes"].items():
        setattr(settings["work_calendar"], name, value)

==> ifcopenshell-0.7.10-py310-none-manylinux_2_31_x86_64.whl: ifcopenshell/api/sequence/edit_work_calendar.py <==
# IfcOpenShell - IFC toolkit and geometry engine
# Copyright (C) 2021 Dion Moult <dion@thinkmoult.com>
#
# This file is part of IfcOpenShell.
#
# IfcOpenShell is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# IfcOpenShell is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with IfcOpenShell.  If not, see <http://www.gnu.org/licenses/>.
import ifcopenshell
from typing import Any


def edit_work_calendar(
    file: ifcopenshell.file, work_calendar: ifcopenshell.entity_instance, attributes: dict[str, Any]
) -> None:
    """Edits the attributes of an IfcWorkCalendar

    For more information about the attributes and data types of an
    IfcWorkCalendar, consult the IFC documentation.

    :param work_calendar: The IfcWorkCalendar entity you want to edit
    :type work_calendar: ifcopenshell.entity_instance
    :param attributes: a dictionary of attribute names and values.
    :type attributes: dict
    :return: None
    :rtype: None

    Example:

    .. code:: python

        # Let's create a new calendar.
        calendar = ifcopenshell.api.sequence.add_work_calendar(model, name="5 Day Week")

        # Let's give it a description
        ifcopenshell.api.sequence.edit_work_calendar(model,
            work_calendar=calendar, attributes={"Description": "Monday to Friday 8 hour days"})
    """
    settings = {"work_calendar": work_calendar, "attributes": attributes}

    for name, value in settings["attributes"].items():
        setattr(settings["work_calendar"], name, value)
